@@ -9,28 +9,28 @@ sub make_tree {
     '+toprule' => 'jsony',
     '+version' => '0.0.1',
     'EOL' => {
-      '.rgx' => qr/(?-xism:\G\r?\n)/
+      '.rgx' => qr/\G\r?\n/
     },
     'LCURLY' => {
-      '.rgx' => qr/(?-xism:\G\{)/
+      '.rgx' => qr/\G\{/
     },
     'LSQUARE' => {
-      '.rgx' => qr/(?-xism:\G\[)/
+      '.rgx' => qr/\G\[/
     },
     'RCURLY' => {
-      '.rgx' => qr/(?-xism:\G\})/
+      '.rgx' => qr/\G\}/
     },
     'RSQUARE' => {
-      '.rgx' => qr/(?-xism:\G\])/
+      '.rgx' => qr/\G\]/
     },
     'bare' => {
-      '.rgx' => qr/(?-xism:\G([^\s\{\}\[\]'",]*[^\s\{\}\[\]'",:]))/
+      '.rgx' => qr/\G([^\s\{\}\[\]'",]*[^\s\{\}\[\]'",:])/
     },
     'comment' => {
-      '.rgx' => qr/(?-xism:\G(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))/
+      '.rgx' => qr/\G(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n)/
     },
     'double' => {
-      '.rgx' => qr/(?-xism:\G"((?:\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})|[^"\x00-\x1f])*)")/
+      '.rgx' => qr/\G"((?:\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})|[^"\x00-\x1f])*)"/
     },
     'jsony' => {
       '.any' => [
@@ -56,32 +56,32 @@ sub make_tree {
       '.ref' => 'node',
       '.sep' => {
         '+eok' => 1,
-        '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+        '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
       }
     },
     'map' => {
       '.all' => [
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '.ref' => 'LCURLY'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '+min' => 0,
           '.ref' => 'pair'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '.ref' => 'RCURLY'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         }
       ]
     },
@@ -104,13 +104,13 @@ sub make_tree {
           '.ref' => 'string'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*:?(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*:?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '.ref' => 'node'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         }
       ]
     },
@@ -130,35 +130,35 @@ sub make_tree {
     'seq' => {
       '.all' => [
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '.ref' => 'LSQUARE'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '+min' => 0,
           '.ref' => 'node',
           '.sep' => {
             '+eok' => 1,
-            '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+            '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*,?(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
           }
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '.ref' => 'RSQUARE'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         }
       ]
     },
     'single' => {
-      '.rgx' => qr/(?-xism:\G'([^']*)')/
+      '.rgx' => qr/\G'([^']*)'/
     },
     'string' => {
       '.ref' => 'scalar'
@@ -170,13 +170,13 @@ sub make_tree {
           '.ref' => 'string'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*:(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*:(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         },
         {
           '.ref' => 'node'
         },
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*/
         }
       ]
     },
@@ -187,7 +187,7 @@ sub make_tree {
     'top_seq_entry' => {
       '.all' => [
         {
-          '.rgx' => qr/(?-xism:\G(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*\-\ +)/
+          '.rgx' => qr/\G(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*\-\ +/
         },
         {
           '.all' => [
@@ -196,7 +196,7 @@ sub make_tree {
               '.ref' => 'node',
               '.sep' => {
                 '+eok' => 1,
-                '.rgx' => qr/(?-xism:\G(?:\ *,\ *\r?\n(?:\s|(?:\#\ .*\r?\n|\#\ *\r?\n|\ *\r?\n))*|\ +))/
+                '.rgx' => qr/\G(?:\ *,\ *\r?\n(?:\s|(?:\#\ .*\r?\n|\#\r?\n|\ *\r?\n))*|\ +)/
               }
             },
             {
